.. _gal-production_and_montecarlo:

Production Functions and Monte Carlo Utilities
==============================================

This section provides examples of how to generate both projectile and crater populations using the :ref:`api-production` component, as well as how to use the functions contained in the :ref:`api-utils-montecarlo` utilities.
